@@ -11,7 +11,7 @@ console.log(alpha);
 //=> [ 'x/foo/a-0/y', 'x/foo/b-1/y', 'x/foo/c-2/y', 'x/foo/d-3/y', 'x/foo/e-4/y' ]
 
 const numeric = braces.expand('{1..5}', {
-  transform(value, index) {
+  transform(value) {
     return 'foo/' + value * 2;
   }
 });
